QudsAppController class

A controller to manager the main QudsApp of the application

Constructors

QudsAppController({Function? onAppSet, required List<QudsProvider> providers, String? encryptionKey, String? encryptionIV})
onAppSet: Called when the app is initialized. encryptionKey, encryptionIV to encrypt the state of the app before saving it in SharedPreferences

Properties

app ↔ QudsApp?
Get the QudsApp set to this controller.
getter/setter pair
encryptionIV → String?
The encryption IV to encrypt/decrypt providers states for save/restore.
final
encryptionKey → String?
The encryption key to encrypt/decrypt providers states for save/restore.
final
hashCode → int
The hash code for this object.
no setterinherited
onAppSet → Function?
Called when an QudsApp set this QudsAppController as its controller.
final
providers → List<QudsProvider>
The list of this controller providers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppStateAsJson() → String?
Serialize the state of the app to be saved later.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreStateInSharedPreferences() → Future<bool>
Restore the app saved state, usually called in the startup of the app.
saveStateInSharedPreferences() → Future<bool>
Save the state of the app in shared preferences, with encryption if required.
setAppStateFromJson(String json) → void
Set the saved state of the app, usually at the startup of the app.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited