QudsListNotifier<T> class

Represnets a list with change notifier for addition and removing.

Inheritance
Available extensions

Constructors

QudsListNotifier({Iterable<T>? initialList, T jsonCreator(Map<String, dynamic>)?})
Create an instance of QudsListNotifier

Properties

first → T
Returns the first element.
no setteroverride
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Returns true if there are no elements in this collection.
no setteroverride
isNotEmpty → bool
Returns true if there is at least one element in this collection.
no setteroverride
iterator → Iterator<T>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
jsonCreator → T Function(Map<String, dynamic>)?
Custom T creator using json map
final
last → T
Returns the last element.
no setteroverride
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
Get the length of the list
no setteroverride
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → T
Checks that this iterable has only one element, and returns that element.
no setteroverride
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(T entry) → void
Add an entry
addAll(Iterable<T> iterable) → void
Appends all objects of iterable to the end of this list.
addAllWithCasting(Iterable iterable) → void
Appends all objects of iterable to the end of this list with casting to T
addWatcher(Function f) → void
Add a watcher that be called when the value changed
any(bool test(T element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() → Map<int, T>
An unmodifiable Map view of this list.
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → QudsListNotifier<R>
A view of this iterable as an iterable of R instances.
override
clear() → void
Remove all entries from this list
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → T
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(T element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(T element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [T? fillValue]) → void
Overwrites a range of elements with fillValue.
firstWhere(bool test(T element), {T orElse()?}) → T
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<T> other) → Iterable<T>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void f(T entry)) → void
Invokes action on each element of this iterable in iteration order.
override
indexOf(T entry, [int start = 0]) → int
The first index of element in this list.
insert(int index, T entry) → void
Insert an entry in specific index
insertAll(int index, Iterable<T> iterable) → void
Insert a collection in specific index
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(T element), {T orElse()?}) → T
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(T e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(T combine(T value, T element)) → T
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(T entry) → bool
Remove an entry Returns true if value was in the list, false otherwise.
removeAt(int index) → void
Remove an entry in specific index
removeLast() → T
Remove the last entry
removeWatcher(Function f) → void
Remove a watcher
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
singleWhere(bool test(T element), {T orElse()?}) → T
The single element that satisfies test.
inherited
skip(int count) → Iterable<T>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(T element)) → Iterable<T>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<T>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(T element)) → Iterable<T>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<T>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<T>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(T element)) → Iterable<T>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited