QudsProvider class abstract

Represent a state manager, holds the values and fires the watchers for any reported change

Constructors

QudsProvider()
Create an instance of QudsProvider

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addWatcher(Function watcher) → void
Add custom watcher to be fired in any reported change
fireWatchers() → void
Fire the watchers
fromMap(Map map) → void
Restore the saved state
getValues() → List<QudsValue>
Gets the desired list of QudsValue to be watched.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeWatcher(Function watcher) → void
Remove an inserted watcher, to stop firing it in any reported change.
toSerializableMap() → Map
Get the state of this provider as map to be serialized
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited