QudsValue<T> class

Represents an Object or QudsListNotifier holder and change notifier. T may be an object or QudsListNotifier

Constructors

QudsValue({required String name, required T value, bool? serializable, T jsonGetter(Map<String, dynamic> json)?})
name: the key name of the value, must be unique

Properties

hashCode → int
The hash code for this object.
no setterinherited
isListNotifier → bool
Weather this value is an instance of QudsListNotifier
no setter
jsonGetter → T Function(Map<String, dynamic> json)?
Custome value generator using json map
final
name → String
The key name of the value, must be unique.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serializable → bool?
Weather the value to be serialized for saving and restoring
final
v ↔ T
Get the current value
getter/setter pair
value ↔ T
Get the current value;
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited